==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_fields/FUNCTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour FUNCTIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FUNCTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONDESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FILENAME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FUNCTIONID_Type", propOrder = {
    "functioncode",
    "functiondescription",
    "filename",
    "classid"
})
public class FUNCTIONID_Type {

    @XmlElement(name = "FUNCTIONCODE", required = true)
    protected String functioncode;
    @XmlElement(name = "FUNCTIONDESCRIPTION")
    protected String functiondescription;
    @XmlElement(name = "FILENAME")
    protected String filename;
    @XmlElement(name = "CLASSID")
    protected CLASSID_Type classid;

    /**
     * Obtient la valeur de la propriété functioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFUNCTIONCODE() {
        return functioncode;
    }

    /**
     * Définit la valeur de la propriété functioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFUNCTIONCODE(String value) {
        this.functioncode = value;
    }

    /**
     * Obtient la valeur de la propriété functiondescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFUNCTIONDESCRIPTION() {
        return functiondescription;
    }

    /**
     * Définit la valeur de la propriété functiondescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFUNCTIONDESCRIPTION(String value) {
        this.functiondescription = value;
    }

    /**
     * Obtient la valeur de la propriété filename.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFILENAME() {
        return filename;
    }

    /**
     * Définit la valeur de la propriété filename.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFILENAME(String value) {
        this.filename = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/FUNCTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FUNCTIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FUNCTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONDESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FILENAME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FUNCTIONID_Type", propOrder = {
    "functioncode",
    "functiondescription",
    "filename",
    "classid"
})
public class FUNCTIONID_Type {

    @XmlElement(name = "FUNCTIONCODE", required = true)
    protected String functioncode;
    @XmlElement(name = "FUNCTIONDESCRIPTION")
    protected String functiondescription;
    @XmlElement(name = "FILENAME")
    protected String filename;
    @XmlElement(name = "CLASSID")
    protected CLASSID_Type classid;

    /**
     * Gets the value of the functioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFUNCTIONCODE() {
        return functioncode;
    }

    /**
     * Sets the value of the functioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFUNCTIONCODE(String value) {
        this.functioncode = value;
    }

    /**
     * Gets the value of the functiondescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFUNCTIONDESCRIPTION() {
        return functiondescription;
    }

    /**
     * Sets the value of the functiondescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFUNCTIONDESCRIPTION(String value) {
        this.functiondescription = value;
    }

    /**
     * Gets the value of the filename property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFILENAME() {
        return filename;
    }

    /**
     * Sets the value of the filename property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFILENAME(String value) {
        this.filename = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

}
